==> loadmychunks-1.2.0%2B1.20.1%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/integ/cct/turtle/UpgradeModeller.java <==
//? if computercraft {
package com.drathonix.loadmychunks.common.integ.cct.turtle;

//? if <=1.19.2 {
/*import com.mojang.math.Vector3f;
*///?}
import dan200.computercraft.api.client.TransformedModel;
//? if >1.18.2 {
import dan200.computercraft.api.client.turtle.TurtleUpgradeModeller;
//?}
import dan200.computercraft.api.turtle.ITurtleAccess;
import dan200.computercraft.api.turtle.ITurtleUpgrade;
import dan200.computercraft.api.turtle.TurtleSide;
//? if >1.19.2 {
import dan200.computercraft.impl.client.ClientPlatformHelper;
import net.minecraft.class_1087;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4590;
import org.joml.Vector3f;
import org.jetbrains.annotations.Nullable;

public class UpgradeModeller<T extends ITurtleUpgrade>
    //? if >1.18.2 {
        implements TurtleUpgradeModeller<T>
    //?}
{
    public static final class_4590 leftTransform = getMatrixFor(-0.45f);
    public static final class_4590 rightTransform = getMatrixFor(-0.05f);

    private static class_4590 getMatrixFor(float offset) {
        return new class_4590(new Vector3f(0.5f + offset, 0.25f, 0.225f),
                null, new Vector3f(0.5f, 0.5f, 0.5f),
                null);
    }
    //? if <=1.20.1 && >1.19.2 {
    @Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess iTurtleAccess, TurtleSide side) {
        class_1799 stack = t.getUpgradeItem(null);
        class_1087 model = class_310.method_1551().method_1480().method_4012().method_3308(stack);
        if (stack.method_7958()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }
    //?}
    //? if <=1.19.2 && >1.18.2 {
    /*@Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess iTurtleAccess, TurtleSide side) {
        return TransformedModel.of(t.getCraftingItem(),side == TurtleSide.LEFT ? leftTransform : rightTransform);
    }
    *///?}


    //? if <1.20.6 && >=1.20.4 {
    /*@Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess turtle, TurtleSide side, CompoundTag compoundTag) {
        ItemStack stack = t.getUpgradeItem(compoundTag);
        BakedModel model = Minecraft.getInstance().getItemRenderer().getItemModelShaper().getItemModel(stack);
        if (stack.hasFoil()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }

    *///?}

    //? if >=1.20.6 {
    /*@Override
    public TransformedModel getModel(ITurtleUpgrade upgrade, @Nullable ITurtleAccess turtle, TurtleSide side, DataComponentPatch data) {
        ItemStack stack = upgrade.getUpgradeItem(data);
        BakedModel model = Minecraft.getInstance().getItemRenderer().getItemModelShaper().getItemModel(stack);
        if (stack.hasFoil()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }
    *///?}
}
//?}

==> loadmychunks-1.2.1%2B1.20.6%2Bfabric-sources.jar: com/drathonix/loadmychunks/common/integ/cct/turtle/UpgradeModeller.java <==
//? if computercraft {
package com.drathonix.loadmychunks.common.integ.cct.turtle;

//? if <=1.19.2 {
/*import com.mojang.math.Vector3f;
*///?}
import dan200.computercraft.api.client.TransformedModel;
//? if >1.18.2 {
import dan200.computercraft.api.client.turtle.TurtleUpgradeModeller;
//?}
import dan200.computercraft.api.turtle.ITurtleAccess;
import dan200.computercraft.api.turtle.ITurtleUpgrade;
import dan200.computercraft.api.turtle.TurtleSide;
//? if >1.19.2 {
import dan200.computercraft.impl.client.ClientPlatformHelper;
import net.minecraft.class_1087;
import net.minecraft.class_1799;
import net.minecraft.class_310;
import net.minecraft.class_4590;
import net.minecraft.class_9326;
import org.joml.Vector3f;
import org.jetbrains.annotations.Nullable;

public class UpgradeModeller<T extends ITurtleUpgrade>
    //? if >1.18.2 {
        implements TurtleUpgradeModeller<T>
    //?}
{
    public static final class_4590 leftTransform = getMatrixFor(-0.45f);
    public static final class_4590 rightTransform = getMatrixFor(-0.05f);

    private static class_4590 getMatrixFor(float offset) {
        return new class_4590(new Vector3f(0.5f + offset, 0.25f, 0.225f),
                null, new Vector3f(0.5f, 0.5f, 0.5f),
                null);
    }
    //? if <=1.20.1 && >1.19.2 {
    /*@Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess iTurtleAccess, TurtleSide side) {
        ItemStack stack = t.getUpgradeItem(null);
        BakedModel model = Minecraft.getInstance().getItemRenderer().getItemModelShaper().getItemModel(stack);
        if (stack.hasFoil()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }
    *///?}
    //? if <=1.19.2 && >1.18.2 {
    /*@Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess iTurtleAccess, TurtleSide side) {
        return TransformedModel.of(t.getCraftingItem(),side == TurtleSide.LEFT ? leftTransform : rightTransform);
    }
    *///?}


    //? if <1.20.6 && >=1.20.4 {
    /*@Override
    public TransformedModel getModel(T t, @Nullable ITurtleAccess turtle, TurtleSide side, CompoundTag compoundTag) {
        ItemStack stack = t.getUpgradeItem(compoundTag);
        BakedModel model = Minecraft.getInstance().getItemRenderer().getItemModelShaper().getItemModel(stack);
        if (stack.hasFoil()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }

    *///?}

    //? if >=1.20.6 {
    @Override
    public TransformedModel getModel(ITurtleUpgrade upgrade, @Nullable ITurtleAccess turtle, TurtleSide side, class_9326 data) {
        class_1799 stack = upgrade.getUpgradeItem(data);
        class_1087 model = class_310.method_1551().method_1480().method_4012().method_3308(stack);
        if (stack.method_7958()) model = ClientPlatformHelper.get().createdFoiledModel(model);
        TransformedModel out = new TransformedModel(model, side == TurtleSide.LEFT ? leftTransform : rightTransform);
        return out;
    }
    //?}
}
//?}
